*****************************************
imageset: generates code for Xcode assets
*****************************************

Reads your ``.xcassets`` directory and generates functions, categories, or constants.
Supports both Swift and Objective-C, and allows custom templates.

============
Installation
============

.. code-block:: bash

    $ pip install imageset

=====
Usage
=====

Just run:

.. code-block:: bash

    $ imageset --help

For details. The category/extension mode seems best to me.